==> haskell-mysql-simple-0.4.9-133-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-43x40zcCfj06LpcJzt2sZ1
key:                  mysql-simple-0.4.9-43x40zcCfj06LpcJzt2sZ1
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  3e62aa059439253906eb32f56a5536be
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-43x40zcCfj06LpcJzt2sZ1
depends:
    attoparsec-0.14.4-LmTKTFLXrumHz4pqfqNh8g base-4.17.2.1
    base16-bytestring-1.0.2.0-4VKZSMAQma4FWplzwntFGI
    blaze-builder-0.4.4.1-1jE2jTKoqGH3aj9MBDpFLw bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-3kJ1IKH2dMGBRp09AOL4Wb
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-KNdIDQJBMfqZw80tRO96W text-2.0.2 time-1.12.2
    vector-0.13.2.0-FDZBPFjQhmHDghUn2Zh3lL

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mysql-simple-0.4.9-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mysql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mysql-simple
version:              0.4.9
visibility:           public
id:                   mysql-simple-0.4.9-Igq8CZbga9ALUFvoO7RsOF
key:                  mysql-simple-0.4.9-Igq8CZbga9ALUFvoO7RsOF
license:              BSD-3-Clause
copyright:            2011 MailRank, Inc.
maintainer:           Paul Rouse <pyr@doynton.org>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/paul-rouse/mysql-simple
synopsis:             A mid-level MySQL client library.
description:
    A mid-level client library for the MySQL database, intended to be
    fast and easy to use.

    /Important licensing note/: This library is BSD-licensed under the
    terms of the MySQL FOSS License Exception
    <http://www.mysql.com/about/legal/licensing/foss-exception/>.

    Since this library links against the GPL-licensed @mysqlclient@
    library, a non-open-source application that uses it /may/ be
    subject to the terms of the GPL.

category:             Database
abi:                  219929e435e439248007916a6fb14b83
exposed:              True
exposed-modules:
    Database.MySQL.Simple Database.MySQL.Simple.Param
    Database.MySQL.Simple.QueryParams
    Database.MySQL.Simple.QueryResults Database.MySQL.Simple.Result
    Database.MySQL.Simple.Types

hidden-modules:       Database.MySQL.Internal.Blaze
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mysql-simple-0.4.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mysql-simple
hs-libraries:         HSmysql-simple-0.4.9-Igq8CZbga9ALUFvoO7RsOF
depends:
    attoparsec-0.14.4-H6DCtC2rXm7CWC54FRqEZL base-4.17.2.1
    base16-bytestring-1.0.2.0-EMXeBMC8GqbAFRIxoGFv6C
    blaze-builder-0.4.4.1-CRExiPUdjbG8JKbY7llSvY bytestring-0.11.5.3
    containers-0.6.7 mysql-0.2.1-2BMjk549PRNI7wSCC4z2cZ
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pcre-light-0.4.1.3-AIyudmpFXzGAtrodeVFMwC text-2.0.2 time-1.12.2
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:
    /usr/share/doc/haskell-mysql-simple/html/mysql-simple.haddock

haddock-html:         /usr/share/doc/haskell-mysql-simple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
